@@ -9,11 +9,16 @@ def main():
 
     group.add_argument(
         "--add_user",
-        help="Add new person to track ADS cites",
+        help="Add new person to track list",
         action="store_true",
     )
     group.add_argument(
-        "--print_users",
+        "--remove_user",
+        help="Remove user from track list",
+        action="store_true",
+    )
+    group.add_argument(
+        "--list_users",
         help="Print user list",
         action="store_true",
     )
@@ -28,12 +33,19 @@ def main():
     group.add_argument(
         "--check", help="Check for any new cites to users papers", action="store_true"
     )
+    parser.add_argument(
+        "--verbose", help="For more output", action="store_true"
+    )
     args = parser.parse_args()
 
-    # Create or update user ADS details
+    # Add a user to the database
     if args.add_user:
         cite_tracker.add_user()
 
+    # Remove a user from the database
+    if args.remove_user:
+        cite_tracker.remove_user()
+
     # Set the ADS API token.
     elif args.set_ads_token is not None:
         cite_tracker.set_ads_token(args.set_ads_token)
@@ -43,9 +55,9 @@ def main():
         cite_tracker.report()
 
     # Print user list.
-    elif args.print_users:
-        cite_tracker.print_users()
+    elif args.list_users:
+        cite_tracker.list_users()
 
     # Check if any new cites have been made to the user since last call
     elif args.check:
-        cite_tracker.check()
+        cite_tracker.check(args.verbose)
